Stan Math Library: stan/math/prim/scal/fun/logical_or.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
logical_or.hpp File Reference

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T1 , typename T2 >
int | stan::math::logical_or (T1 x1, T2 x2)
| The logical or function which returns 1 if either argument is unequal to zero and 0 otherwise. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.